aboutsummaryrefslogtreecommitdiffstats
path: root/examples/charts/nesteddonuts.py
diff options
context:
space:
mode:
Diffstat (limited to 'examples/charts/nesteddonuts.py')
-rw-r--r--examples/charts/nesteddonuts.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/examples/charts/nesteddonuts.py b/examples/charts/nesteddonuts.py
index 77bbabfc7..09c77d022 100644
--- a/examples/charts/nesteddonuts.py
+++ b/examples/charts/nesteddonuts.py
@@ -39,14 +39,14 @@
##
#############################################################################
"""PySide2 port of the Nested Donuts example from Qt v5.x"""
import sys
-from PySide2.QtCore import Qt, QTimer
-from PySide2.QtGui import QPainter
-from PySide2.QtWidgets import QApplication, QGridLayout, QWidget
-from PySide2.QtCharts import QtCharts
+from PySide6.QtCore import Qt, QTimer
+from PySide6.QtGui import QPainter
+from PySide6.QtWidgets import QApplication, QGridLayout, QWidget
+from PySide6.QtCharts import QtCharts
from random import randrange
from functools import partial
@@ -39,14 +39,14 @@
##
#############################################################################
-"""PySide2 port of the Nested Donuts example from Qt v5.x"""
+"""PySide6 port of the Nested Donuts example from Qt v5.x"""
import sys